# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class UserSearchRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserSearchRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'sort_order': 'str',
            'sort_by': 'str',
            'page_size': 'int',
            'page_number': 'int',
            'return_fields': 'list[str]',
            'expand': 'list[str]',
            'query': 'list[UserSearchCriteria]'
        }

        self.attribute_map = {
            'sort_order': 'sortOrder',
            'sort_by': 'sortBy',
            'page_size': 'pageSize',
            'page_number': 'pageNumber',
            'return_fields': 'returnFields',
            'expand': 'expand',
            'query': 'query'
        }

        self._sort_order = None
        self._sort_by = None
        self._page_size = None
        self._page_number = None
        self._return_fields = None
        self._expand = None
        self._query = None

    @property
    def sort_order(self):
        """
        Gets the sort_order of this UserSearchRequest.


        :return: The sort_order of this UserSearchRequest.
        :rtype: str
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """
        Sets the sort_order of this UserSearchRequest.


        :param sort_order: The sort_order of this UserSearchRequest.
        :type: str
        """
        allowed_values = ["ASC", "DESC", "SCORE"]
        if sort_order not in allowed_values:
            raise ValueError(
                "Invalid value for `sort_order`, must be one of {0}"
                .format(allowed_values)
            )

        self._sort_order = sort_order

    @property
    def sort_by(self):
        """
        Gets the sort_by of this UserSearchRequest.


        :return: The sort_by of this UserSearchRequest.
        :rtype: str
        """
        return self._sort_by

    @sort_by.setter
    def sort_by(self, sort_by):
        """
        Sets the sort_by of this UserSearchRequest.


        :param sort_by: The sort_by of this UserSearchRequest.
        :type: str
        """
        
        self._sort_by = sort_by

    @property
    def page_size(self):
        """
        Gets the page_size of this UserSearchRequest.


        :return: The page_size of this UserSearchRequest.
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """
        Sets the page_size of this UserSearchRequest.


        :param page_size: The page_size of this UserSearchRequest.
        :type: int
        """
        
        self._page_size = page_size

    @property
    def page_number(self):
        """
        Gets the page_number of this UserSearchRequest.


        :return: The page_number of this UserSearchRequest.
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """
        Sets the page_number of this UserSearchRequest.


        :param page_number: The page_number of this UserSearchRequest.
        :type: int
        """
        
        self._page_number = page_number

    @property
    def return_fields(self):
        """
        Gets the return_fields of this UserSearchRequest.


        :return: The return_fields of this UserSearchRequest.
        :rtype: list[str]
        """
        return self._return_fields

    @return_fields.setter
    def return_fields(self, return_fields):
        """
        Sets the return_fields of this UserSearchRequest.


        :param return_fields: The return_fields of this UserSearchRequest.
        :type: list[str]
        """
        
        self._return_fields = return_fields

    @property
    def expand(self):
        """
        Gets the expand of this UserSearchRequest.


        :return: The expand of this UserSearchRequest.
        :rtype: list[str]
        """
        return self._expand

    @expand.setter
    def expand(self, expand):
        """
        Sets the expand of this UserSearchRequest.


        :param expand: The expand of this UserSearchRequest.
        :type: list[str]
        """
        
        self._expand = expand

    @property
    def query(self):
        """
        Gets the query of this UserSearchRequest.


        :return: The query of this UserSearchRequest.
        :rtype: list[UserSearchCriteria]
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this UserSearchRequest.


        :param query: The query of this UserSearchRequest.
        :type: list[UserSearchCriteria]
        """
        
        self._query = query

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class QualityAudit(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QualityAudit - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'user': 'User',
            'timestamp': 'str',
            'entity': 'AuditEntity',
            'level': 'str',
            'action': 'str',
            'status': 'str',
            'changes': 'list[Change]',
            'entity_type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'user': 'user',
            'timestamp': 'timestamp',
            'entity': 'entity',
            'level': 'level',
            'action': 'action',
            'status': 'status',
            'changes': 'changes',
            'entity_type': 'entityType',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._user = None
        self._timestamp = None
        self._entity = None
        self._level = None
        self._action = None
        self._status = None
        self._changes = None
        self._entity_type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this QualityAudit.
        The globally unique identifier for the object.

        :return: The id of this QualityAudit.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QualityAudit.
        The globally unique identifier for the object.

        :param id: The id of this QualityAudit.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this QualityAudit.


        :return: The name of this QualityAudit.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this QualityAudit.


        :param name: The name of this QualityAudit.
        :type: str
        """
        
        self._name = name

    @property
    def user(self):
        """
        Gets the user of this QualityAudit.


        :return: The user of this QualityAudit.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this QualityAudit.


        :param user: The user of this QualityAudit.
        :type: User
        """
        
        self._user = user

    @property
    def timestamp(self):
        """
        Gets the timestamp of this QualityAudit.


        :return: The timestamp of this QualityAudit.
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this QualityAudit.


        :param timestamp: The timestamp of this QualityAudit.
        :type: str
        """
        
        self._timestamp = timestamp

    @property
    def entity(self):
        """
        Gets the entity of this QualityAudit.


        :return: The entity of this QualityAudit.
        :rtype: AuditEntity
        """
        return self._entity

    @entity.setter
    def entity(self, entity):
        """
        Sets the entity of this QualityAudit.


        :param entity: The entity of this QualityAudit.
        :type: AuditEntity
        """
        
        self._entity = entity

    @property
    def level(self):
        """
        Gets the level of this QualityAudit.


        :return: The level of this QualityAudit.
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this QualityAudit.


        :param level: The level of this QualityAudit.
        :type: str
        """
        
        self._level = level

    @property
    def action(self):
        """
        Gets the action of this QualityAudit.


        :return: The action of this QualityAudit.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this QualityAudit.


        :param action: The action of this QualityAudit.
        :type: str
        """
        
        self._action = action

    @property
    def status(self):
        """
        Gets the status of this QualityAudit.


        :return: The status of this QualityAudit.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this QualityAudit.


        :param status: The status of this QualityAudit.
        :type: str
        """
        
        self._status = status

    @property
    def changes(self):
        """
        Gets the changes of this QualityAudit.


        :return: The changes of this QualityAudit.
        :rtype: list[Change]
        """
        return self._changes

    @changes.setter
    def changes(self, changes):
        """
        Sets the changes of this QualityAudit.


        :param changes: The changes of this QualityAudit.
        :type: list[Change]
        """
        
        self._changes = changes

    @property
    def entity_type(self):
        """
        Gets the entity_type of this QualityAudit.


        :return: The entity_type of this QualityAudit.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this QualityAudit.


        :param entity_type: The entity_type of this QualityAudit.
        :type: str
        """
        
        self._entity_type = entity_type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this QualityAudit.
        The URI for this object

        :return: The self_uri of this QualityAudit.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this QualityAudit.
        The URI for this object

        :param self_uri: The self_uri of this QualityAudit.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class UserConversationSummary(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserConversationSummary - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'user_id': 'str',
            'call': 'MediaSummary',
            'callback': 'MediaSummary',
            'email': 'MediaSummary',
            'chat': 'MediaSummary',
            'social_expression': 'MediaSummary',
            'video': 'MediaSummary'
        }

        self.attribute_map = {
            'user_id': 'userId',
            'call': 'call',
            'callback': 'callback',
            'email': 'email',
            'chat': 'chat',
            'social_expression': 'socialExpression',
            'video': 'video'
        }

        self._user_id = None
        self._call = None
        self._callback = None
        self._email = None
        self._chat = None
        self._social_expression = None
        self._video = None

    @property
    def user_id(self):
        """
        Gets the user_id of this UserConversationSummary.


        :return: The user_id of this UserConversationSummary.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this UserConversationSummary.


        :param user_id: The user_id of this UserConversationSummary.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def call(self):
        """
        Gets the call of this UserConversationSummary.


        :return: The call of this UserConversationSummary.
        :rtype: MediaSummary
        """
        return self._call

    @call.setter
    def call(self, call):
        """
        Sets the call of this UserConversationSummary.


        :param call: The call of this UserConversationSummary.
        :type: MediaSummary
        """
        
        self._call = call

    @property
    def callback(self):
        """
        Gets the callback of this UserConversationSummary.


        :return: The callback of this UserConversationSummary.
        :rtype: MediaSummary
        """
        return self._callback

    @callback.setter
    def callback(self, callback):
        """
        Sets the callback of this UserConversationSummary.


        :param callback: The callback of this UserConversationSummary.
        :type: MediaSummary
        """
        
        self._callback = callback

    @property
    def email(self):
        """
        Gets the email of this UserConversationSummary.


        :return: The email of this UserConversationSummary.
        :rtype: MediaSummary
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this UserConversationSummary.


        :param email: The email of this UserConversationSummary.
        :type: MediaSummary
        """
        
        self._email = email

    @property
    def chat(self):
        """
        Gets the chat of this UserConversationSummary.


        :return: The chat of this UserConversationSummary.
        :rtype: MediaSummary
        """
        return self._chat

    @chat.setter
    def chat(self, chat):
        """
        Sets the chat of this UserConversationSummary.


        :param chat: The chat of this UserConversationSummary.
        :type: MediaSummary
        """
        
        self._chat = chat

    @property
    def social_expression(self):
        """
        Gets the social_expression of this UserConversationSummary.


        :return: The social_expression of this UserConversationSummary.
        :rtype: MediaSummary
        """
        return self._social_expression

    @social_expression.setter
    def social_expression(self, social_expression):
        """
        Sets the social_expression of this UserConversationSummary.


        :param social_expression: The social_expression of this UserConversationSummary.
        :type: MediaSummary
        """
        
        self._social_expression = social_expression

    @property
    def video(self):
        """
        Gets the video of this UserConversationSummary.


        :return: The video of this UserConversationSummary.
        :rtype: MediaSummary
        """
        return self._video

    @video.setter
    def video(self, video):
        """
        Sets the video of this UserConversationSummary.


        :param video: The video of this UserConversationSummary.
        :type: MediaSummary
        """
        
        self._video = video

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class WorkspaceMember(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WorkspaceMember - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'workspace': 'UriReference',
            'member_type': 'str',
            'member': 'UriReference',
            'user': 'User',
            'group': 'Group',
            'security_profile': 'SecurityProfile',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'workspace': 'workspace',
            'member_type': 'memberType',
            'member': 'member',
            'user': 'user',
            'group': 'group',
            'security_profile': 'securityProfile',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._workspace = None
        self._member_type = None
        self._member = None
        self._user = None
        self._group = None
        self._security_profile = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this WorkspaceMember.
        The globally unique identifier for the object.

        :return: The id of this WorkspaceMember.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WorkspaceMember.
        The globally unique identifier for the object.

        :param id: The id of this WorkspaceMember.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this WorkspaceMember.


        :return: The name of this WorkspaceMember.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WorkspaceMember.


        :param name: The name of this WorkspaceMember.
        :type: str
        """
        
        self._name = name

    @property
    def workspace(self):
        """
        Gets the workspace of this WorkspaceMember.


        :return: The workspace of this WorkspaceMember.
        :rtype: UriReference
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """
        Sets the workspace of this WorkspaceMember.


        :param workspace: The workspace of this WorkspaceMember.
        :type: UriReference
        """
        
        self._workspace = workspace

    @property
    def member_type(self):
        """
        Gets the member_type of this WorkspaceMember.


        :return: The member_type of this WorkspaceMember.
        :rtype: str
        """
        return self._member_type

    @member_type.setter
    def member_type(self, member_type):
        """
        Sets the member_type of this WorkspaceMember.


        :param member_type: The member_type of this WorkspaceMember.
        :type: str
        """
        allowed_values = ["USER", "GROUP"]
        if member_type not in allowed_values:
            raise ValueError(
                "Invalid value for `member_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._member_type = member_type

    @property
    def member(self):
        """
        Gets the member of this WorkspaceMember.


        :return: The member of this WorkspaceMember.
        :rtype: UriReference
        """
        return self._member

    @member.setter
    def member(self, member):
        """
        Sets the member of this WorkspaceMember.


        :param member: The member of this WorkspaceMember.
        :type: UriReference
        """
        
        self._member = member

    @property
    def user(self):
        """
        Gets the user of this WorkspaceMember.


        :return: The user of this WorkspaceMember.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this WorkspaceMember.


        :param user: The user of this WorkspaceMember.
        :type: User
        """
        
        self._user = user

    @property
    def group(self):
        """
        Gets the group of this WorkspaceMember.


        :return: The group of this WorkspaceMember.
        :rtype: Group
        """
        return self._group

    @group.setter
    def group(self, group):
        """
        Sets the group of this WorkspaceMember.


        :param group: The group of this WorkspaceMember.
        :type: Group
        """
        
        self._group = group

    @property
    def security_profile(self):
        """
        Gets the security_profile of this WorkspaceMember.


        :return: The security_profile of this WorkspaceMember.
        :rtype: SecurityProfile
        """
        return self._security_profile

    @security_profile.setter
    def security_profile(self, security_profile):
        """
        Sets the security_profile of this WorkspaceMember.


        :param security_profile: The security_profile of this WorkspaceMember.
        :type: SecurityProfile
        """
        
        self._security_profile = security_profile

    @property
    def self_uri(self):
        """
        Gets the self_uri of this WorkspaceMember.
        The URI for this object

        :return: The self_uri of this WorkspaceMember.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this WorkspaceMember.
        The URI for this object

        :param self_uri: The self_uri of this WorkspaceMember.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

